workflow.CachingWorkflow

|  | ## Cheshire3 Object Model: Class CachingWorkflow

Module workflow :: Class CachingWorkflow

## Class CachingWorkflow
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
         baseObjects.Workflow --+
                                |
                   SimpleWorkflow --+
                                    |
                                   CachingWorkflow

Slightly faster workflow implementation that caches the objects. Object not to be used in one database and then another database without first calling workflow.load_cache(session, newDatabaseObject)
Instance Methods

__init__(self, session, node, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
load_cache(self, session, db)
_handleConfigNode(self, session, node)
_handleLog(self, node)
_handleObject(self, node)
_handleSplit(self, node)
Inherited from `SimpleWorkflow` (private): `_handleFlow`, `_handleForEach`, `_handleFork` Inherited from `baseObjects.Workflow`: `process` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

code |
splitN |
splitCode |
objcache |
objrefs |
database |
defaultLogger |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: SimpleWorkflow.__init__

### load_cache(self, session, db) | source code

### _handleConfigNode(self, session, node) | source code
Overrides: SimpleWorkflow._handleConfigNode

### _handleLog(self, node) | source code
Overrides: SimpleWorkflow._handleLog

### _handleObject(self, node) | source code
Overrides: SimpleWorkflow._handleObject

### _handleSplit(self, node) | source code
Overrides: SimpleWorkflow._handleSplit

Class Variable Details

    ### code Value:
        None

    ### splitN Value:
        0

    ### splitCode Value:
        {}

    ### objcache Value:
        {}

    ### objrefs Value:
        None

    ### database Value:
        None

    ### defaultLogger Value:
        None